pub struct NetherBiomeSource {
seed: u64,
climate_sampler: NetherClimateSampler,
}Expand description
Multi-noise biome source for the nether.
Uses compiled nether density functions to sample temperature and vegetation,
then looks up the biome in the nether parameter list (RTree).
Equivalent to vanilla’s MultiNoiseBiomeSource with the nether preset.
Fields
seed: u64climate_sampler: NetherClimateSamplerImplementations
Sourceimpl NetherBiomeSource
impl NetherBiomeSource
fn chunk_sampler(&self) -> ChunkBiomeSampler<'_>